# lythonic.periodic

Time and scheduling utilities.

::: lythonic.periodic
    options:
      show_root_heading: false
      members:
        - SimulatedTime
        - stime
        - Frequency
        - FrequencyOffset
        - IntervalUnit
        - Interval
        - Moment
        - PeriodicTask
        - run_all
        - dt_to_bytes
        - dt_from_bytes
        - date_from_name
        - adjust_as_of_date
